Package 'DemographicTable'

Title: Create Demographic Table
Description: To create demographic table with simple summary statistics, with optional comparison(s) over one or more groups.
Authors: Tingting Zhan [aut, cre] (ORCID: <https://orcid.org/0000-0001-9971-4844>)
Maintainer: Tingting Zhan <[email protected]>
License: GPL-2
Version: 0.3.0
Built: 2026-05-31 06:11:18 UTC
Source: https://github.com/tingtingzhan/demographictable

Help Index


DemographicTable: Create Demographic Table

Description

To create demographic table with simple summary statistics, with optional comparison(s) over one or more groups.

Note

Help files of individual functions are intentionally suppressed in the pdf manual. Users are encouraged to get started with

vignette('intro', package = 'DemographicTable')

Author(s)

Maintainer: Tingting Zhan [email protected] (ORCID)

Authors: